@@ -102,7 +102,7 @@ create3D <- function(dcm, mode="integer", transpose=TRUE, pixelData=TRUE,
       }
     } else {
       for (z in 1:Z) {
-        img[,,z] <- readDICOMFile(names(dcm$hdr)[z])$img
+        img[,,z] <- rereadDICOMFile(names(dcm$hdr)[z])$img
       }
     }
   }
@@ -183,7 +183,7 @@ create4D <- function(dcm, mode="integer", transpose=TRUE, pixelData=TRUE,
     } else {
       for (w in 1:ntimes) {
         k <- 1
-        dicomInfoImage <- readDICOMFile(names(dcm$hdr)[w])$img
+        dicomInfoImage <- rereadDICOMFile(names(dcm$hdr)[w])$img
         for (i in (X/x):1) {
           for (j in 1:(Y/y)) {
             img[,,k,w] <- dicomInfoImage[((i-1)*x)+1:x, ((j-1)*y)+1:y]
@@ -235,7 +235,7 @@ create4D <- function(dcm, mode="integer", transpose=TRUE, pixelData=TRUE,
       for (z in 1:Z) {
         zz <- (z - 1) %% nslices + 1
         ww <- (z - 1) %/% nslices + 1
-        img[,,zz,ww] <- readDICOMFile(names(dcm$hdr)[index[z]])$img
+        img[,,zz,ww] <- rereadDICOMFile(names(dcm$hdr)[index[z]])$img
       }
     }
   }
